@@ -1,6 +1,8 @@
 
 #include <test.hpp>
 
+#include <array>
+
 #include "t/repeated_packed_fixed32/repeated_packed_fixed32_testcase.pb.h"
 
 TEST_CASE("write repeated packed fixed32 field and check with libprotobuf") {
@@ -11,12 +13,12 @@ TEST_CASE("write repeated packed fixed32 field and check with libprotobuf") {
     TestRepeatedPackedFixed32::Test msg;
 
     SECTION("empty") {
-        const uint32_t data[] = { 17UL };
+        const std::array<uint32_t, 1> data = {{ 17UL }};
         pw.add_packed_fixed32(1, std::begin(data), std::begin(data) /* !!!! */);
     }
 
     SECTION("one") {
-        const uint32_t data[] = { 17UL };
+        const std::array<uint32_t, 1> data = {{ 17UL }};
         pw.add_packed_fixed32(1, std::begin(data), std::end(data));
 
         msg.ParseFromString(buffer);
@@ -26,7 +28,7 @@ TEST_CASE("write repeated packed fixed32 field and check with libprotobuf") {
     }
 
     SECTION("many") {
-        const uint32_t data[] = { 17UL, 0UL, 1UL, std::numeric_limits<uint32_t>::max() };
+        const std::array<uint32_t, 4> data = {{ 17UL, 0UL, 1UL, std::numeric_limits<uint32_t>::max() }};
         pw.add_packed_fixed32(1, std::begin(data), std::end(data));
 
         msg.ParseFromString(buffer);
@@ -47,7 +49,7 @@ TEST_CASE("write from different types of iterators and check with libprotobuf")
     TestRepeatedPackedFixed32::Test msg;
 
     SECTION("from uint16_t") {
-        const uint16_t data[] = { 1, 4, 9, 16, 25 };
+        const std::array<uint16_t, 5> data = {{ 1, 4, 9, 16, 25 }};
 
         pw.add_packed_fixed<uint32_t>(1, std::begin(data), std::end(data));
     }
